Adds asset lists to av_runShiny() internal data.
Details
Add Asset Groups
Lists are specified in normalized form. Duplicate list names with those currently in use are replaced.
Adds asset lists to av_runShiny() internal data.
Add Asset Groups
Lists are specified in normalized form. Duplicate list names with those currently in use are replaced.