av_add_assetgroups: App database functions

View source: R/app_db.R

av_add_assetgroupsR Documentation

App database functions

Description

Adds asset lists to av_runShiny() internal data.

Usage

av_add_assetgroups(indta)

Arguments

indta

A data.frame with two columns c("listnm","ticker") with one or more lines for each "listnm"

Details

Lists are specified in normalized form. Duplicate list names with those currently in use are replaced.

Value

Nothing

See Also

av_runShiny()

Examples

## Not run: 
newtickers <- c("QQQ","QQQE","NDX")
av_add_assetgroups(data.table(listnm=rep("nasdaq",length(newtickers)),ticker=newtickers))
# To remove an asset list, just use an empty string for the ticker
av_add_assetgroups(data.table(listnm=c("new"),ticker=c("")))

## End(Not run)


alphavantagepf documentation built on June 24, 2026, 5:08 p.m.