| av_add_assetgroups | R Documentation |
Adds asset lists to av_runShiny() internal data.
av_add_assetgroups(indta)
indta |
A data.frame with two columns |
Lists are specified in normalized form. Duplicate list names with those currently in use are replaced.
Nothing
av_runShiny()
## Not run:
newtickers <- c("QQQ","QQQE","NDX")
av_add_assetgroups(data.table(listnm=rep("nasdaq",length(newtickers)),ticker=newtickers))
# To remove an asset list, just use an empty string for the ticker
av_add_assetgroups(data.table(listnm=c("new"),ticker=c("")))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.