av_api_key: Set the Alpha Vantage API Key

View source: R/av_api_key.R

av_api_keyR Documentation

Set the Alpha Vantage API Key

Description

av_api_key() sets Alphavantage API key and entitlement code

Usage

av_api_key(api_key, entitlement = NULL)

Arguments

api_key

A character string with your Alpha Vantage API Key.

entitlement

A character string with your Alpha Vantage entitlement status. If not "delayed" or "realtime" entitlement not added to API string.

Details

The Alpha Vantage API key must be set prior to using av_get_pf(). You can obtain an API key at the Alpha Vantage Website.

Value

Invisibly returns two item list with API key and entitlement string once set). Use print method to view.

See Also

av_get_pf()

Examples

## Not run: 
av_api_key("YOUR_API_KEY",entitlement="delayed")
av_get_pf("IBM", "TIME_SERIES_INTRADAY")

## End(Not run)


alphavantagepf documentation built on Jan. 23, 2026, 1:06 a.m.