View source: R/av_extract_opts.R
| av_grep_opts | R Documentation |
Extract data from Alpha Vantage returned data
av_grep_opts(
indta,
grepstring = "F,M,C,otm",
spot = NULL,
mindays = 3,
startdt = Sys.Date(),
mindelta = 0.05,
dropsymbol = FALSE
)
indta |
A data.table as returned by | |||||||||||||||||||
grepstring |
(default
| |||||||||||||||||||
spot |
(default | |||||||||||||||||||
mindays |
(default 3). Minimum number of days to expiration to be passed through from | |||||||||||||||||||
startdt |
(default | |||||||||||||||||||
mindelta |
(default | |||||||||||||||||||
dropsymbol |
(default |
av_get_pf() returns a large list of options. This function helps to narrow down the list by maturity and moneyness.
A reduced set of options obtained from av_get_pf() using Alphavantage HISTORICAL_OPTIONS function.
av_get_pf()
## Not run:
av_get_pf("IBM","HISTORICAL_OPTIONS") |> av_grep_opts("F,M,put",mindays=2)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.