R/av_appRfuncs.R
avsh_clipboard.Rd
Copies a data.frame to the clipboard, with a status message if relevant
avsh_clipboard(x, title = "")
A data.frame or equivalent.
data.frame
String to add to a message printed if relevant
Nothing